# PDG mass and width tables

This directory contains the tables of masses and widths provided by the Particle Data Group.
In addition to the most recent one, also the ones of previous years are included since they
might be useful when comparing to the numerics of older papers.

The data files have been downloaded from the following URLs:

- http://pdg.lbl.gov/2006/mcdata/mass_width_2006.mc
- http://pdg.lbl.gov/2008/mcdata/mass_width_2008.mc
- http://pdg.lbl.gov/2010/mcdata/mass_width_2010.mcd
- http://pdg.lbl.gov/2011/mcdata/mass_width_2011.mcd
- http://pdg.lbl.gov/2012/mcdata/mass_width_2012.mcd
- http://pdg.lbl.gov/2013/mcdata/mass_width_2013.mcd
- http://pdg.lbl.gov/2014/mcdata/mass_width_2014.mcd
- http://pdg.lbl.gov/2015/mcdata/mass_width_2015.mcd
